import { OnProgressParameters, PDFDocumentProxy } from 'pdfjs-dist';
interface PdfLoaderOptions {
    /**
     * URL to the PDF document
     */
    documentURL: string;
    /**
     * Container element to display the loading progress
     */
    containerHTMLElement?: HTMLElement;
    /**
     * Callback function to display the loading progress
     * @param progress Loading progress parameters
     */
    onLoading?: (progress: OnProgressParameters) => HTMLDivElement | void;
    /**
     * Callback function when the PDF document is loaded
     * @param pdfDocument PDF document object
     */
    loaded?: (pdfDocument: PDFDocumentProxy) => void;
    /**
     * Callback function to display the error message
     * @param error Error
     * @returns Error message element or void if external error message is used
     */
    errorMessage?: (error: Error) => HTMLDivElement | void;
    /**
     * Callback function to handle the error
     * @param error Error
     */
    onError?: (error: Error) => void;
    workerSrc?: string;
}
export declare class PdfLoader {
    private documentURL;
    private onLoading;
    private onLoaded;
    private errorMessage;
    private onError;
    private workerSrc;
    private containerHTMLElement;
    private pdfLoadingTask;
    private pdfDocument;
    private error;
    private loadingProgress;
    constructor(options: PdfLoaderOptions);
    loadDocument(): Promise<PDFDocumentProxy>;
    private updateUI;
}
export {};
